@@ -2,9 +2,14 @@ from ._python_calamine import (
     CalamineError,
     CalamineSheet,
     CalamineWorkbook,
+    PasswordError,
     SheetMetadata,
     SheetTypeEnum,
     SheetVisibleEnum,
+    WorkbookClosed,
+    WorksheetNotFound,
+    XmlError,
+    ZipError,
     load_workbook,
 )
 
@@ -12,8 +17,13 @@ __all__ = (
     "CalamineError",
     "CalamineSheet",
     "CalamineWorkbook",
+    "PasswordError",
     "SheetMetadata",
     "SheetTypeEnum",
     "SheetVisibleEnum",
+    "WorksheetNotFound",
+    "XmlError",
+    "ZipError",
+    "WorkbookClosed",
     "load_workbook",
 )
